@@ -195,6 +195,25 @@ def spin_forever():
 def spinning_distraction():
     p = multiprocessing.Process(target=spin_forever)
     p.start()
-    yield
-    p.terminate()
+    try:
+        yield
+    finally:
+        p.terminate()
 
+
+def maybe_add_ellipses(s, maxlen=72):
+    """
+    If string s is longer than maxlen, truncate it and add on ... to
+    the end.
+
+    >>> maybe_add_ellipses('abcdef')
+    'abcdef'
+    >>> maybe_add_ellipses('abcdef', 3)
+    'abc...'
+    """
+
+    if len(s) <= maxlen:
+        return s
+
+    else:
+        return "%s..." % s[:maxlen]
